@@ -2,8 +2,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Run::AfterMint;
-# ABSTRACT: Execute a command after a new dist is minted
-$Dist::Zilla::Plugin::Run::AfterMint::VERSION = '0.026';
+# ABSTRACT: Execute a command after a new distribution is minted
+
+our $VERSION = '0.043';
+
 use Moose;
 with qw(
   Dist::Zilla::Role::AfterMint
@@ -14,7 +16,7 @@ use namespace::autoclean;
 
 sub after_mint {
   my ($self, $param) = @_;
-  $self->call_script({
+  $self->_call_script({
     dir     => $param->{mint_root},
     minting => 1,
   });
@@ -27,7 +29,7 @@ sub after_mint {
 #pod
 #pod =head1 DESCRIPTION
 #pod
-#pod This plugin executes the specified command after minting a new dist.
+#pod This plugin executes the specified command after minting a new distribution.
 #pod
 #pod =head1 CONVERSIONS
 #pod
@@ -46,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Run::AfterMint - Execute a command after a new dist is minted
+Dist::Zilla::Plugin::Run::AfterMint - Execute a command after a new distribution is minted
 
 =head1 VERSION
 
-version 0.026
+version 0.043
 
 =head1 SYNOPSIS
 
@@ -59,18 +61,29 @@ version 0.026
 
 =head1 DESCRIPTION
 
-This plugin executes the specified command after minting a new dist.
+This plugin executes the specified command after minting a new distribution.
 
 =head1 CONVERSIONS
 
 See L<Dist::Zilla::Plugin::Run/CONVERSIONS>
 for the list of common formatting variables available to all plugins.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
