@@ -3,18 +3,20 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::AfterRelease;
 # ABSTRACT: execute a command of the distribution after release
-$Dist::Zilla::Plugin::Run::AfterRelease::VERSION = '0.026';
+
+our $VERSION = '0.043';
+
 use Moose;
 with qw(
-    Dist::Zilla::Role::AfterRelease
-    Dist::Zilla::Plugin::Run::Role::Runner
+  Dist::Zilla::Role::AfterRelease
+  Dist::Zilla::Plugin::Run::Role::Runner
 );
 
 use namespace::autoclean;
 
 sub after_release {
   my ( $self, $archive ) = @_;
-  $self->call_script({
+  $self->_call_script({
     archive =>  $archive,
     pos     => [$archive, sub { $self->zilla->version }]
   });
@@ -23,12 +25,12 @@ sub after_release {
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::AfterRelease]
-#pod   run = script/myapp_after.pl --archive %s --version %s
+#pod   run = script/myapp_after.pl --archive %a --dir %d --version %v
 #pod
 #pod or
 #pod
 #pod   [Run::AfterRelease / MyAppAfter]
-#pod   run = script/myapp_after.pl %s %s
+#pod   run = script/myapp_after.pl %a %d %v
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -43,7 +45,7 @@ sub after_release {
 #pod
 #pod =for :list
 #pod * The 1st C<%s> will be replaced by the archive of the release.
-#pod * The 2nd C<%s> will be replaced by the dist version.
+#pod * The 2nd C<%s> will be replaced by the distribution version.
 #pod
 #pod =cut
 
@@ -61,17 +63,17 @@ Dist::Zilla::Plugin::Run::AfterRelease - execute a command of the distribution a
 
 =head1 VERSION
 
-version 0.026
+version 0.043
 
 =head1 SYNOPSIS
 
   [Run::AfterRelease]
-  run = script/myapp_after.pl --archive %s --version %s
+  run = script/myapp_after.pl --archive %a --dir %d --version %v
 
 or
 
   [Run::AfterRelease / MyAppAfter]
-  run = script/myapp_after.pl %s %s
+  run = script/myapp_after.pl %a %d %v
 
 =head1 DESCRIPTION
 
@@ -92,15 +94,26 @@ The 1st C<%s> will be replaced by the archive of the release.
 
 =item *
 
-The 2nd C<%s> will be replaced by the dist version.
+The 2nd C<%s> will be replaced by the distribution version.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
