@@ -3,18 +3,20 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Release;
 # ABSTRACT: execute a command of the distribution on release
-$Dist::Zilla::Plugin::Run::Release::VERSION = '0.026';
+
+our $VERSION = '0.043';
+
 use Moose;
 with qw(
-    Dist::Zilla::Role::Releaser
-    Dist::Zilla::Plugin::Run::Role::Runner
+  Dist::Zilla::Role::Releaser
+  Dist::Zilla::Plugin::Run::Role::Runner
 );
 
 use namespace::autoclean;
 
 sub release {
   my ( $self, $archive ) = @_;
-  $self->call_script({
+  $self->_call_script({
     archive =>  $archive,
     pos     => [$archive]
   });
@@ -23,12 +25,12 @@ sub release {
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::Release]
-#pod   run = script/myapp_deploy.pl %s
+#pod   run = script/myapp_deploy.pl %d %v
 #pod
 #pod or
 #pod
 #pod   [Run::Release / MyAppDeploy]
-#pod   run = script/myapp_deploy.pl %s
+#pod   run = script/myapp_deploy.pl %d %v
 #pod
 #pod =head1 DESCRIPTION
 #pod
@@ -62,17 +64,17 @@ Dist::Zilla::Plugin::Run::Release - execute a command of the distribution on rel
 
 =head1 VERSION
 
-version 0.026
+version 0.043
 
 =head1 SYNOPSIS
 
   [Run::Release]
-  run = script/myapp_deploy.pl %s
+  run = script/myapp_deploy.pl %d %v
 
 or
 
   [Run::Release / MyAppDeploy]
-  run = script/myapp_deploy.pl %s
+  run = script/myapp_deploy.pl %d %v
 
 =head1 DESCRIPTION
 
@@ -95,11 +97,22 @@ The 1st C<%s> will be replaced by the archive of the release.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
