@@ -3,7 +3,9 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Test;
 # ABSTRACT: execute a command of the distribution after build
-$Dist::Zilla::Plugin::Run::Test::VERSION = '0.026';
+
+our $VERSION = '0.043';
+
 use Moose;
 with qw(
     Dist::Zilla::Role::TestRunner
@@ -15,7 +17,7 @@ use namespace::autoclean;
 sub test {
     my ($self, $dir) = @_;
 
-    $self->call_script({
+    $self->_call_script({
         dir =>  $dir
     });
 }
@@ -25,7 +27,6 @@ sub test {
 #pod   [Run::Test]
 #pod   run = script/tester.pl --name %n --version %v some_file.ext
 #pod
-#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod This plugin executes the specified command during the test phase.
@@ -59,7 +60,7 @@ Dist::Zilla::Plugin::Run::Test - execute a command of the distribution after bui
 
 =head1 VERSION
 
-version 0.026
+version 0.043
 
 =head1 SYNOPSIS
 
@@ -83,11 +84,22 @@ for the list of common formatting variables available to all plugins.
 
 There are no positional parameters for this plugin.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Run>
+(or L<bug-Dist-Zilla-Plugin-Run@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Run@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
 
